@@ -1,4 +1,5 @@
 from django.core.cache.backends import memcached
+
 from django_prometheus.cache.metrics import (
     django_cache_get_total,
     django_cache_hits_total,
@@ -6,7 +7,7 @@ from django_prometheus.cache.metrics import (
 )
 
 
-class MemcachedCache(memcached.MemcachedCache):
+class MemcachedCache(memcached.PyLibMCCache):
     """Inherit memcached to add metrics about hit/miss ratio"""
 
     def get(self, key, default=None, version=None):
