@@ -4,10 +4,11 @@ from django_prometheus.db import (
     errors_total,
     execute_many_total,
     execute_total,
+    query_duration_seconds,
 )
 
 
-class ExceptionCounterByType(object):
+class ExceptionCounterByType:
     """A context manager that counts exceptions by type.
 
     Exceptions increment the provided counter, whose last label's name
@@ -24,7 +25,7 @@ class ExceptionCounterByType(object):
     def __init__(self, counter, type_label="type", extra_labels=None):
         self._counter = counter
         self._type_label = type_label
-        self._labels = extra_labels
+        self._labels = dict(extra_labels)  # Copy labels since we modify them.
 
     def __enter__(self):
         pass
@@ -35,13 +36,13 @@ class ExceptionCounterByType(object):
             self._counter.labels(**self._labels).inc()
 
 
-class DatabaseWrapperMixin(object):
+class DatabaseWrapperMixin:
     """Extends the DatabaseWrapper to count connections and cursors."""
 
     def get_new_connection(self, *args, **kwargs):
         connections_total.labels(self.alias, self.vendor).inc()
         try:
-            return super(DatabaseWrapperMixin, self).get_new_connection(*args, **kwargs)
+            return super().get_new_connection(*args, **kwargs)
         except Exception:
             connection_errors_total.labels(self.alias, self.vendor).inc()
             raise
@@ -57,24 +58,24 @@ def ExportingCursorWrapper(cursor_class, alias, vendor):
     vendor name.
     """
 
+    labels = {"alias": alias, "vendor": vendor}
+
     class CursorWrapper(cursor_class):
         """Extends the base CursorWrapper to count events."""
 
         def execute(self, *args, **kwargs):
             execute_total.labels(alias, vendor).inc()
-            with ExceptionCounterByType(
-                errors_total, extra_labels={"alias": alias, "vendor": vendor}
+            with query_duration_seconds.labels(**labels).time(), (
+                ExceptionCounterByType(errors_total, extra_labels=labels)
             ):
-                return super(CursorWrapper, self).execute(*args, **kwargs)
+                return super().execute(*args, **kwargs)
 
         def executemany(self, query, param_list, *args, **kwargs):
             execute_total.labels(alias, vendor).inc(len(param_list))
             execute_many_total.labels(alias, vendor).inc(len(param_list))
-            with ExceptionCounterByType(
-                errors_total, extra_labels={"alias": alias, "vendor": vendor}
+            with query_duration_seconds.labels(**labels).time(), (
+                ExceptionCounterByType(errors_total, extra_labels=labels)
             ):
-                return super(CursorWrapper, self).executemany(
-                    query, param_list, *args, **kwargs
-                )
+                return super().executemany(query, param_list, *args, **kwargs)
 
     return CursorWrapper
